@@ -1,11 +1,12 @@
 use serde::*;
 
-#[derive(Serialize, Deserialize)]
+#[derive(Serialize, Deserialize, Default)]
 pub struct Visual {
     pub html: Option<String>,
     pub text: Option<String>,
     pub image: Option<String>,
     pub log: Option<String>,
+    pub markdown: Option<String>,
 }
 
 pub trait Visualize {
